==> python-braintree_3.38.0.orig.tar.gz: braintree_python-3.38.0/tests/unit/test_exports.py <==
from tests.test_helper import *
import braintree

class TestExports(unittest.TestCase):
    def test_exports_properties(self):
        self.assertNotEqual(braintree.AchMandate, None)
        self.assertNotEqual(braintree.AddOn, None)
        self.assertNotEqual(braintree.AddOnGateway, None)
        self.assertNotEqual(braintree.Address, None)
        self.assertNotEqual(braintree.AddressGateway, None)
        self.assertNotEqual(braintree.AmexExpressCheckoutCard, None)
        self.assertNotEqual(braintree.AndroidPayCard, None)
        self.assertNotEqual(braintree.ApplePayCard, None)
        self.assertNotEqual(braintree.BraintreeGateway, None)
        self.assertNotEqual(braintree.ClientToken, None)
        self.assertNotEqual(braintree.Configuration, None)
        self.assertNotEqual(braintree.CredentialsParser, None)
        self.assertNotEqual(braintree.CreditCard, None)
        self.assertNotEqual(braintree.CreditCardGateway, None)
        self.assertNotEqual(braintree.CreditCardVerification, None)
        self.assertNotEqual(braintree.CreditCardVerificationSearch, None)
        self.assertNotEqual(braintree.Customer, None)
        self.assertNotEqual(braintree.CustomerGateway, None)
        self.assertNotEqual(braintree.CustomerSearch, None)
        self.assertNotEqual(braintree.Descriptor, None)
        self.assertNotEqual(braintree.Disbursement, None)
        self.assertNotEqual(braintree.Discount, None)
        self.assertNotEqual(braintree.DiscountGateway, None)
        self.assertNotEqual(braintree.Environment, None)
        self.assertNotEqual(braintree.ErrorCodes, None)
        self.assertNotEqual(braintree.ErrorResult, None)
        self.assertNotEqual(braintree.Errors, None)
        self.assertNotEqual(braintree.EuropeBankAccount, None)
        self.assertNotEqual(braintree.IdealPayment, None)
        self.assertNotEqual(braintree.Merchant, None)
        self.assertNotEqual(braintree.MerchantAccount, None)
        self.assertNotEqual(braintree.MerchantAccountGateway, None)
        self.assertNotEqual(braintree.PartnerMerchant, None)
        self.assertNotEqual(braintree.PaymentInstrumentType, None)
        self.assertNotEqual(braintree.PaymentMethod, None)
        self.assertNotEqual(braintree.PaymentMethodNonce, None)
        self.assertNotEqual(braintree.PayPalAccount, None)
        self.assertNotEqual(braintree.Plan, None)
        self.assertNotEqual(braintree.PlanGateway, None)
        self.assertNotEqual(braintree.ResourceCollection, None)
        self.assertNotEqual(braintree.RiskData, None)
        self.assertNotEqual(braintree.Search, None)
        self.assertNotEqual(braintree.SettlementBatchSummary, None)
        self.assertNotEqual(braintree.SignatureService, None)
        self.assertNotEqual(braintree.StatusEvent, None)
        self.assertNotEqual(braintree.Subscription, None)
        self.assertNotEqual(braintree.SubscriptionGateway, None)
        self.assertNotEqual(braintree.SubscriptionSearch, None)
        self.assertNotEqual(braintree.SubscriptionStatusEvent, None)
        self.assertNotEqual(braintree.SuccessfulResult, None)
        self.assertNotEqual(braintree.TestingGateway, None)
        self.assertNotEqual(braintree.ThreeDSecureInfo, None)
        self.assertNotEqual(braintree.Transaction, None)
        self.assertNotEqual(braintree.TransactionAmounts, None)
        self.assertNotEqual(braintree.TransactionDetails, None)
        self.assertNotEqual(braintree.TransactionGateway, None)
        self.assertNotEqual(braintree.TransactionSearch, None)
        self.assertNotEqual(braintree.TransparentRedirect, None)
        self.assertNotEqual(braintree.TransparentRedirectGateway, None)
        self.assertNotEqual(braintree.UnknownPaymentMethod, None)
        self.assertNotEqual(braintree.UsBankAccount, None)
        self.assertNotEqual(braintree.ValidationErrorCollection, None)
        self.assertNotEqual(braintree.VenmoAccount, None)
        self.assertNotEqual(braintree.Version, None)
        self.assertNotEqual(braintree.WebhookNotification, None)
        self.assertNotEqual(braintree.WebhookNotificationGateway, None)
        self.assertNotEqual(braintree.WebhookTesting, None)
        self.assertNotEqual(braintree.WebhookTestingGateway, None)

==> python-braintree_3.57.1.orig.tar.gz: braintree_python-3.57.1/tests/unit/test_exports.py <==
from tests.test_helper import *
import braintree

class TestExports(unittest.TestCase):
    def test_exports_properties(self):
        self.assertNotEqual(braintree.AchMandate, None)
        self.assertNotEqual(braintree.AddOn, None)
        self.assertNotEqual(braintree.AddOnGateway, None)
        self.assertNotEqual(braintree.Address, None)
        self.assertNotEqual(braintree.AddressGateway, None)
        self.assertNotEqual(braintree.AmexExpressCheckoutCard, None)
        self.assertNotEqual(braintree.AndroidPayCard, None)
        self.assertNotEqual(braintree.ApplePayCard, None)
        self.assertNotEqual(braintree.BraintreeGateway, None)
        self.assertNotEqual(braintree.ClientToken, None)
        self.assertNotEqual(braintree.Configuration, None)
        self.assertNotEqual(braintree.CredentialsParser, None)
        self.assertNotEqual(braintree.CreditCard, None)
        self.assertNotEqual(braintree.CreditCardGateway, None)
        self.assertNotEqual(braintree.CreditCardVerification, None)
        self.assertNotEqual(braintree.CreditCardVerificationSearch, None)
        self.assertNotEqual(braintree.Customer, None)
        self.assertNotEqual(braintree.CustomerGateway, None)
        self.assertNotEqual(braintree.CustomerSearch, None)
        self.assertNotEqual(braintree.Descriptor, None)
        self.assertNotEqual(braintree.Disbursement, None)
        self.assertNotEqual(braintree.Discount, None)
        self.assertNotEqual(braintree.DiscountGateway, None)
        self.assertNotEqual(braintree.Environment, None)
        self.assertNotEqual(braintree.ErrorCodes, None)
        self.assertNotEqual(braintree.ErrorResult, None)
        self.assertNotEqual(braintree.Errors, None)
        self.assertNotEqual(braintree.EuropeBankAccount, None)
        # NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
        # DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
        self.assertNotEqual(braintree.IdealPayment, None)
        self.assertNotEqual(braintree.Merchant, None)
        self.assertNotEqual(braintree.MerchantAccount, None)
        self.assertNotEqual(braintree.MerchantAccountGateway, None)
        self.assertNotEqual(braintree.PartnerMerchant, None)
        self.assertNotEqual(braintree.PaymentInstrumentType, None)
        self.assertNotEqual(braintree.PaymentMethod, None)
        self.assertNotEqual(braintree.PaymentMethodNonce, None)
        self.assertNotEqual(braintree.PayPalAccount, None)
        self.assertNotEqual(braintree.Plan, None)
        self.assertNotEqual(braintree.PlanGateway, None)
        self.assertNotEqual(braintree.ResourceCollection, None)
        self.assertNotEqual(braintree.RiskData, None)
        self.assertNotEqual(braintree.Search, None)
        self.assertNotEqual(braintree.SettlementBatchSummary, None)
        self.assertNotEqual(braintree.SignatureService, None)
        self.assertNotEqual(braintree.StatusEvent, None)
        self.assertNotEqual(braintree.Subscription, None)
        self.assertNotEqual(braintree.SubscriptionGateway, None)
        self.assertNotEqual(braintree.SubscriptionSearch, None)
        self.assertNotEqual(braintree.SubscriptionStatusEvent, None)
        self.assertNotEqual(braintree.SuccessfulResult, None)
        self.assertNotEqual(braintree.TestingGateway, None)
        self.assertNotEqual(braintree.ThreeDSecureInfo, None)
        self.assertNotEqual(braintree.Transaction, None)
        self.assertNotEqual(braintree.TransactionAmounts, None)
        self.assertNotEqual(braintree.TransactionDetails, None)
        self.assertNotEqual(braintree.TransactionGateway, None)
        self.assertNotEqual(braintree.TransactionSearch, None)
        self.assertNotEqual(braintree.TransparentRedirect, None)
        self.assertNotEqual(braintree.TransparentRedirectGateway, None)
        self.assertNotEqual(braintree.UnknownPaymentMethod, None)
        self.assertNotEqual(braintree.UsBankAccount, None)
        self.assertNotEqual(braintree.ValidationErrorCollection, None)
        self.assertNotEqual(braintree.VenmoAccount, None)
        self.assertNotEqual(braintree.Version, None)
        self.assertNotEqual(braintree.WebhookNotification, None)
        self.assertNotEqual(braintree.WebhookNotificationGateway, None)
        self.assertNotEqual(braintree.WebhookTesting, None)
        self.assertNotEqual(braintree.WebhookTestingGateway, None)
